/* ***** BEGIN LICENSE BLOCK *****
   - Version: MPL 1.1/GPL 2.0/LGPL 2.1
   -
   - The contents of this file are subject to the Mozilla Public License Version
   - 1.1 (the "License"); you may not use this file except in compliance with
   - the License. You may obtain a copy of the License at
   - http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS IS" basis,
   - WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
   - for the specific language governing rights and limitations under the
   - License.
   -
   - The Original Code is MozTweak.
   -
   - The Initial Developer of the Original Code is Marek Wawoczny.
   - Portions created by the Initial Developer are Copyright (C) 2002
   - the Initial Developer. All Rights Reserved.
   -
   - Contributor(s):
   - Marek Wawoczny (Marek.Wawoczny@GmbH.rubikon.pl)
   -
   - Alternatively, the contents of this file may be used under the terms of
   - either the GNU General Public License Version 2 or later (the "GPL"), or
   - the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
   - in which case the provisions of the GPL or the LGPL are applicable instead
   - of those above. If you wish to allow use of your version of this file only
   - under the terms of either the GPL or the LGPL, and not to allow others to
   - use your version of this file under the terms of the MPL, indicate your
   - decision by deleting the provisions above and replace them with the notice
   - and other provisions required by the LGPL or the GPL. If you do not delete
   - the provisions above, a recipient may use your version of this file under
   - the terms of any one of the MPL, the GPL or the LGPL.
   -
   - ***** END LICENSE BLOCK ***** */

var nsIRDFService = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);

var headerSets = nsIRDFService.GetDataSource(getHeaderSetsDatasourceURI());
var headerFields = ["authorwrote", "ondate", "separator", "colon", "locale", "type", "originalmessage"];

var Observer = {
  onBeginLoad: function(aSink) {},
  onInterrupt: function(aSink) {},
  onResume: function(aSink) {},

  onEndLoad: function(aSink) {
    var headerField = document.getElementById("moztweak.mail.header");

    try {
       headerField.selectedItem = document.getElementById(getPref("moztweak.mail.header", "char"));
    }
    catch (err) {
       setPref("moztweak.mail.header", "char", "rdf:2$sWU2$3");
       headerField.selectedItem = document.getElementById("rdf:2$sWU2$3");
    }

    setReplyHeader();
  },

  onError: function(aSink, aStatus, aErrorMsg) {
    alert(aErrorMsg);
  }
};

function Startup() {
  var headerField = document.getElementById("moztweak.mail.header");
  if (headerField)
  {
    var gData = parent.hPrefWindow.wsm.dataManager.pageData["chrome://moztweak/content/pref-mail-header.xul"];

    gData.DatasourceURI = getHeaderSetsDatasourceURI();

    parent.hPrefWindow.registerOKCallbackFunc(flushDataSource);

    headerField.database.AddDataSource(headerSets);
    headerField.builder.rebuild();

    headerSets.QueryInterface(Components.interfaces.nsIRDFXMLSink).addXMLSinkObserver(Observer);
    headerSets.QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Refresh(false);
  }
}

function flushDataSource() {
  var gData = parent.hPrefWindow.wsm.dataManager.pageData["chrome://moztweak/content/pref-mail-header.xul"];
  var nsIRDFService = Components.classes["@mozilla.org/rdf/rdf-service;1"].getService(Components.interfaces.nsIRDFService);

  if (gData.DatasourceURI) {
    if (nsIRDFService.GetDataSource(gData.DatasourceURI).QueryInterface(Components.interfaces.nsIRDFRemoteDataSource)) {
      nsIRDFService.GetDataSource(gData.DatasourceURI).QueryInterface(Components.interfaces.nsIRDFRemoteDataSource).Flush();
    }
  }
}

function buildReplyHeader() {
  var DateTime = new Date();
  var nsIScriptableDateFormat = Components.classes["@mozilla.org/intl/scriptabledateformat;1"].getService(Components.interfaces.nsIScriptableDateFormat);
  var DateTimeFormat = nsIScriptableDateFormat.FormatDateTime(
                                 document.getElementById("mailnews.reply_header_locale").value,
                                 nsIScriptableDateFormat.dateFormatShort,
                                 nsIScriptableDateFormat.timeFormatNoSeconds,
                                 DateTime.getFullYear(), DateTime.getMonth()+1,
                                 DateTime.getDate(), DateTime.getHours(),
                                 DateTime.getMinutes(), DateTime.getSeconds());

  var replyHeader = document.getElementById("mailnews.reply_header");

  switch (document.getElementById("mailnews.reply_header_type").value) {
    case "0":
      replyHeader.value = null;
      break;
    case "1":
      replyHeader.value = document.getElementById("mailnews.reply_header_authorwrote").value.replace(/%s/, "Micha\u0142 Wo\u0142odyjowski") + document.getElementById("mailnews.reply_header_colon").value;
      break;
    case "2":
      replyHeader.value = document.getElementById("mailnews.reply_header_ondate").value.replace(/%s/, DateTimeFormat) + document.getElementById("mailnews.reply_header_separator").value + document.getElementById("mailnews.reply_header_authorwrote").value.replace(/%s/, "Micha\u0142 Wo\u0142odyjowski") + document.getElementById("mailnews.reply_header_colon").value;
      break;
    case "3":
      replyHeader.value = document.getElementById("mailnews.reply_header_authorwrote").value.replace(/%s/, "Micha\u0142 Wo\u0142odyjowski") + document.getElementById("mailnews.reply_header_separator").value + document.getElementById("mailnews.reply_header_ondate").value.replace(/%s/, DateTimeFormat) + document.getElementById("mailnews.reply_header_colon").value;
      break;
  }
}

function changeReplyHeader(ID, newValue) {
  var headerField = document.getElementById("moztweak.mail.header");

  var oldValue = headerSets.GetTarget(nsIRDFService.GetResource(headerField.selectedItem.id), nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#" + ID.split("mailnews.reply_header_")[1]), true);

  if (oldValue) {
    oldValue = oldValue.QueryInterface(Components.interfaces.nsIRDFLiteral);
  }

  if (newValue) {
    newValue = nsIRDFService.GetLiteral(newValue);
  }

  if (oldValue && !newValue) {
    headerSets.Unassert(nsIRDFService.GetResource(headerField.selectedItem.id), nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#" + ID.split("mailnews.reply_header_")[1]), oldValue);
  }
  else if (!oldValue && newValue) {
    headerSets.Assert(nsIRDFService.GetResource(headerField.selectedItem.id), nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#" + ID.split("mailnews.reply_header_")[1]), newValue, true);
  }
  else {
    headerSets.Change(nsIRDFService.GetResource(headerField.selectedItem.id), nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#" + ID.split("mailnews.reply_header_")[1]), oldValue, newValue);
  }

  buildReplyHeader();
}

function disableFields(state) {
  for (var i = 0; i < headerFields.length; ++i) {
    if (headerFields[i] != "type") {
      document.getElementById("mailnews.reply_header_" + headerFields[i]).disabled = state;
    }
  }

  document.getElementById("deleteHeaderSet").disabled = state;
}

function setReplyHeader() {
  var headerField = document.getElementById("moztweak.mail.header");

  for (var i = 0; i < headerFields.length; ++i) {
    var field = document.getElementById("mailnews.reply_header_" + headerFields[i]);

    var value = headerSets.GetTarget(nsIRDFService.GetResource(headerField.selectedItem.id), nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#" + headerFields[i]), true);

    if (value) {
      value = value.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
      field.value = value;
    }
  }

  if (headerField.selectedItem.id == "rdf:2$sWU2$3" || headerField.selectedItem.id == "rdf:eUx$WU9#1") {
    disableFields(true);
  }
  else {
    disableFields(false);
  }

  buildReplyHeader();
}

function addHeaderSet() {
  var headerSetName = window.prompt(getMsg("newHeaderNameDialogBox.property"));

  if (!headerSetName) {
    return;
  }

  var headerField = document.getElementById("moztweak.mail.header");

  var newNode=nsIRDFService.GetAnonymousResource();

  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#name"), nsIRDFService.GetLiteral(headerSetName), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#authorwrote"), nsIRDFService.GetLiteral("U\u017Cytkownik %s napisa\u0142"), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#separator"), nsIRDFService.GetLiteral(", "), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#colon"), nsIRDFService.GetLiteral(":"), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#locale"), nsIRDFService.GetLiteral("pl-PL"), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#type"), nsIRDFService.GetLiteral("2"), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#originalmessage"), nsIRDFService.GetLiteral("--- Wiadomo\u015B\u0107 oryginalna ---"), true);
  headerSets.Assert(newNode, nsIRDFService.GetResource("http://MozillaPL.sf.net/rdf#ondate"), nsIRDFService.GetLiteral("Dnia %s"), true);

  headerField.selectedItem = document.getElementById(newNode.Value);

  setReplyHeader();
}

function deleteHeaderSet() {
  if (!window.confirm(getMsg("deleteHeaderDialogBox.property"))) {
    return;
  }

  var headerField = document.getElementById("moztweak.mail.header");

  var removeNode = nsIRDFService.GetResource(headerField.selectedItem.id);
  var ArcLabelsOut = headerSets.ArcLabelsOut(removeNode);

  while(ArcLabelsOut.hasMoreElements()) {
    var Arc = ArcLabelsOut.getNext();
    var Targets = headerSets.GetTargets(removeNode, Arc, true);

    while (Targets.hasMoreElements()) {
      var Target = Targets.getNext();

      headerSets.Unassert(removeNode, Arc, Target, true);
    }
  }

  headerField.selectedItem = document.getElementById("rdf:2$sWU2$3");

  setReplyHeader();
}

function getHeaderSetsDatasourceURI() {
  var directoryServices = Components.classes["@mozilla.org/file/directory_service;1"].getService()

  var profileDirectory = directoryServices.QueryInterface(Components.interfaces.nsIProperties).get("ProfD", Components.interfaces.nsIFile);
  var profileDefaultsDirectory = directoryServices.QueryInterface(Components.interfaces.nsIProperties).get("ProfDefNoLoc", Components.interfaces.nsIFile);

  var File = new Components.Constructor("@mozilla.org/file/local;1", "nsILocalFile", "initWithPath");
  var FileURL = new Components.Constructor("@mozilla.org/network/standard-url;1", "nsIFileURL");

  try {
    var headersFile = new File(profileDirectory.path);
    var headersFileURL = new FileURL();

    headersFile.append("moztweak.rdf");
    headersFileURL.file = headersFile;

    if (headersFile.exists()) {
      return headersFileURL.spec;
    }
    else {
      var defaultHeadersFile = new File(profileDefaultsDirectory.path);

      defaultHeadersFile.append("moztweak.rdf");
      defaultHeadersFile.copyTo(profileDirectory, null);
      return headersFileURL.spec;
    }
  }
  catch (err) {
    return null;
  }
}

function testAlertNotification() {
  showAlert("chrome://messenger/skin/icons/new-mail-alert.png", getMsg("AlertNotificationTitle.property"), getMsg("AlertNotificationMessage.property"), true, null, null);
}

function applyAlertSettings() {
  setPref("alerts.slideIncrement", "int", document.getElementById("alerts.slideIncrement").value);
  setPref("alerts.slideIncrementTime", "int", document.getElementById("alerts.slideIncrementTime").value);
  setPref("alerts.totalOpenTime", "int", document.getElementById("alerts.totalOpenTime").value);
  setPref("alerts.height", "int", document.getElementById("alerts.height").value);
}

function resetAlertSettings() {
  setPref("alerts.slideIncrement", "int", 1);
  setPref("alerts.slideIncrementTime", "int", 10);
  setPref("alerts.totalOpenTime", "int", 4000);
  setPref("alerts.height", "int", 50);

  document.getElementById("alerts.slideIncrement").value = 1;
  document.getElementById("alerts.slideIncrementTime").value = 10;
  document.getElementById("alerts.totalOpenTime").value = 4000;
  document.getElementById("alerts.height").value = 50;
}
